from django.conf import settings
from django.contrib import admin
from django.urls import include, path

from rest_framework.authtoken.views import obtain_auth_token

from huscy.appointments.urls import router as appointments_router
from huscy.bookings.urls import router as bookings_router
from huscy.rooms.urls import router as rooms_router
from huscy.users.urls import router as users_router
from huscy_project.views import health_check


urlpatterns = [
    path('admin/', admin.site.urls),
    path('health_check/', health_check),
    path('api-auth-token/', obtain_auth_token),
    path('api/appointments/', include(appointments_router.urls)),
    path('api/attributes/', include('huscy.attributes.urls')),
    path('api/bookings/', include(bookings_router.urls)),
    path('api/projects/', include('huscy.projects.urls')),
    path('api/', include('huscy.project_documents.urls')),
    path('api/', include('huscy.project_ethics.urls')),
    path('api/recruitment/', include('huscy.recruitment.urls')),
    path('api/rooms/', include(rooms_router.urls)),
    path('api/subjects/', include('huscy.subjects.urls')),
    path('api/users/', include(users_router.urls)),
]

if settings.DEBUG:
    urlpatterns.append(
        path('api-auth/', include('rest_framework.urls')),
    )



import os
import sys
import argparse

from django.core.management import ManagementUtility


CURRENT_PYTHON = sys.version_info[:2]
REQUIRED_PYTHON = (3, 5)

if CURRENT_PYTHON < REQUIRED_PYTHON:
    sys.stderr.write('This version requires Python {}.{} or above - you are running {}.{}\n'.format(
        *(REQUIRED_PYTHON + CURRENT_PYTHON)))
    exit(1)


def main():
    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers(help='commands', dest='command')

    start_parser = subparsers.add_parser('start', help='creates new huscy environment')
    start_parser.add_argument('project_name', help='django project name')

    args = parser.parse_args()
    if args.command == 'start':
        print("start was selected")
        create_project(project_name=args.project_name)


def create_project(project_name):
    try:
        __import__(project_name)
    except ImportError:
        pass
    else:
        sys.exit(f'{project_name} conficts with the name of an existing Python module and cannot'
                 'be used as a project name. Please try another name.')

    print(f'Creating a huscy project called {project_name}')

    import huscy_project
    huscy_project_path = os.path.dirname(huscy_project.__file__)
    template_path = os.path.join(huscy_project_path, 'project_template')

    utility_args = ['django-admin.py',
                    'startproject',
                    f'--template={template_path}',
                    project_name]
    utility = ManagementUtility(utility_args)
    utility.execute()

    print(f'Success! {project_name} has been created')


if __name__ == "__main__":
    main()



"""
Django settings for {{ project_name }} project.

Generated by 'django-admin startproject' using Django {{ django_version }}.

For more information on this file, see
https://docs.djangoproject.com/en/{{ docs_version }}/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/{{ docs_version }}/ref/settings/
"""

import os

from django.core.exceptions import ImproperlyConfigured


# Build paths inside the project like this: os.path.join(PROJECT_DIR, ...)
PROJECT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/{{ docs_version }}/howto/deployment/checklist/
SECRET_KEY = '{{ secret_key }}'

ALLOWED_HOSTS = os.environ.get('ALLOWED_HOSTS', 'localhost').split(',')

CORS_ORIGIN_WHITELIST = os.environ.get('CORS_ORIGIN_WHITELIST', 'http://localhost').split(',')

DEBUG = os.environ.get('DEBUG', 'True') == 'True'
if DEBUG is True:
    warning_message = 'SECURITY WARNING: don\'t run with debug turned on in production!'
    print(f'{67 * "*"}\n* {warning_message} *\n{67 * "*"}')


# Application definition
INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',

    'corsheaders',
    'guardian',
    'rest_framework.authtoken',

    'huscy.appointments',
    'huscy.attributes',
    'huscy.bookings',
    'huscy.project_documents',
    'huscy.project_ethics',
    'huscy.projects',
    'huscy.pseudonyms',
    'huscy.recruitment',
    'huscy.rooms',
    'huscy.subjects',
    'huscy.users',
]

if DEBUG is True:
    INSTALLED_APPS.append(
        'rest_framework',
    )


AUTHENTICATION_BACKENDS = (
    'django.contrib.auth.backends.ModelBackend',
    'guardian.backends.ObjectPermissionBackend',
)

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',

    'corsheaders.middleware.CorsMiddleware',
]


REST_FRAMEWORK = {
    'DEFAULT_AUTHENTICATION_CLASSES': [
        'rest_framework.authentication.SessionAuthentication',
        'rest_framework.authentication.TokenAuthentication',
    ],
}

ROOT_URLCONF = 'config.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.template.context_processors.static',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'config.wsgi.application'

# Database
# https://docs.djangoproject.com/en/{{ docs_version }}/ref/settings/#databases
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql',
        'HOST': 'localhost',
        'PORT': 5432,
        'NAME': 'huscy',
        'USER': 'huscy',
        'PASSWORD': '123',
    },
}

if DEBUG is False and 'default' in DATABASES and DATABASES['default'].get('PASSWORD') == '123':
    raise ImproperlyConfigured('Password mustn\'t be \'123\' in production. '
                               'Rethink your safety policy!')


# Password validation
# https://docs.djangoproject.com/en/{{ docs_version }}/ref/settings/#auth-password-validators

if DEBUG is False:
    AUTH_PASSWORD_VALIDATORS = [
        {
            'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
        },
        {
            'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
        },
        {
            'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
        },
        {
            'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
        },
    ]


# Internationalization
# https://docs.djangoproject.com/en/{{ docs_version }}/topics/i18n/

LANGUAGE_CODE = 'en-us'

USE_I18N = True

USE_L10N = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/{{ docs_version }}/howto/static-files/

STATIC_URL = '/static/'
STATIC_ROOT = os.path.join(PROJECT_DIR, 'static/')

MEDIA_URL = '/media/'
MEDIA_ROOT = os.path.join(PROJECT_DIR, 'media/')



from setuptools import find_packages, setup

from huscy_project import __version__


entry_points = {
    'console_scripts': [
        'huscy=huscy_project.bin.huscy:main',
    ],
}

extras_require = {
    'testing': [
        'tox',
    ],
}

install_requires = [
    # public dependencies
    'Django',
    'django-auth-ldap',
    'django-cors-headers',
    'django-guardian',
    'psycopg2',

    # local dependencies
    'huscy.appointments',
    'huscy.attributes',
    'huscy.bookings',
    'huscy.project_documents',
    'huscy.project_ethics',
    'huscy.projects',
    'huscy.pseudonyms',
    'huscy.recruitment',
    'huscy.rooms',
    'huscy.subjects',
    'huscy.users',
]

setup(
    name='huscy-project',
    version=__version__,

    description='integration project for some apps',

    author='Alexander Tyapkov, Mathias Goldau, Stefan Bunde',
    author_email='tyapkov@gmail.com, goldau@cbs.mpg.de, stefanbunde+git@posteo.de',

    packages=find_packages(),
    include_package_data=True,

    entry_points=entry_points,
    install_requires=install_requires,
    extras_require=extras_require,
)
